pub unsafe fn foreign_requested(slot: NonNull<u8>) -> usize
Read back the requested size a foreign free recorded.
slot must still be on a foreign list, untouched since [push_foreign] wrote it.
slot
push_foreign